@@ -10,7 +10,7 @@ class Config(TrainValConfigBase):
     USE_tqdm_TRAIN = True
     INPUT_SIZE = (252,196)
     BATCH_SIZE = 64
-    NUM_EPOCHS = 200
+    MAX_EPOCHS = 200
     BALANCE_CLASSES = True
     VAL_INTERVAL = 1
     WEIGHTS_SAVE_INTERVAL = 1
