@@ -28,6 +28,8 @@ def test(cfg):
     print('Num images: %s'%(len(fs)))
     for i,f in enumerate(fs):
         img=cv2.imread(f)
+        if img is None:
+            raise Exception('Failed to load %s'%(f))
         cls,prob=predictor.predict(img)
 
         if cfg.SPLIT_BY_PROB:
